module.exports = defineTest({
	description: 'do not fail for literal values from recursive return values'
});
